# SymTMM : A symbolic implementation of the Transfer Matrix Method

The method implemented is similar to what is presented in "Propagation of sound in porous
media" by Allard & Atalla (2009, 978047074661-5).

Note: this software is provided as-is under the MIT License. It has been built as a proof
of concept and must not be used in production without proper testing.

